.. Copyright (C) 2015-2019 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2015-2019 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

`RStudio <https://www.rstudio.com/>`_ is an Integrated Development Environment for
the R programming language.

This Ansible role can be used to deploy RStudio Server, which is RStudio
implemented as a web application accessible in a browser.
